@@ -3,8 +3,6 @@
  *		salvo option by: Chuck A DeGaul
  * with improved user interface, autoconfiguration and code cleanup
  *		by Eric S. Raymond <esr@snark.thyrsus.com>
- *
- * $Id: bs.c,v 1.10 2003/12/24 21:34:28 esr Exp $
  */
 
 #include <curses.h>
@@ -14,6 +12,8 @@
 #include <assert.h>
 #include <time.h>
 #include <unistd.h>
+#include <stdlib.h>
+#include <stdbool.h>
 
 #ifndef SIGIOT
 #define SIGIOT SIGABRT
@@ -154,7 +154,7 @@ static char board[2][BWIDTH][BDEPTH];
 static int turn;			/* 0=player, 1=computer */
 static int plywon=0, cpuwon=0;		/* How many games has each won? */
 
-static int salvo, blitz, closepack;
+static bool salvo, blitz, closepack;
 
 #define	PR	(void)addstr
 
@@ -523,8 +523,6 @@ static void initgame(void)
 
 static int getcoord(int atcpu)
 {
-    int ny, nx, c;
-
     if (atcpu)
 	cgoto(cury,curx);
     else
@@ -532,6 +530,8 @@ static int getcoord(int atcpu)
     (void)refresh();
     for (;;)
     {
+	int ny, nx, c;
+
 	if (atcpu)
 	{
 	    (void) mvprintw(CYBASE + BDEPTH+1, CXBASE+11, "(%d, %c)", curx, 'A'+cury);
@@ -715,11 +715,10 @@ static bool checkplace(int b, ship_t *ss, int vis)
 static int awinna(void)
 {
     int i, j;
-    ship_t *ss;
 
     for(i=0; i<2; ++i)
     {
-	ss = (i) ? cpuship : plyship;
+	ship_t *ss = (i) ? cpuship : plyship;
 	for(j=0; j < SHIPTYPES; ++j, ++ss)
 	    if(ss->length > ss->hits)
 		break;
@@ -747,9 +746,12 @@ static ship_t *hitship(int x, int y)
 		return((ship_t *)NULL);
 	    else				/* sunk! */
 	    {
-		int i, j;
+		int i;
 
 		if (!closepack)
+		{
+		    int j;
+
 		    for (j = -1; j <= 1; j++)
 		    {
 			int bx = ss->x + j * xincr[(ss->dir + 2) % 8];
@@ -784,6 +786,7 @@ static ship_t *hitship(int x, int y)
 			    }
 			}
 		    }
+		}
 
 		for (i = 0; i < ss->length; ++i)
 		{
@@ -841,10 +844,12 @@ static int plyturn(void)
     cgoto(cury, curx);
 #ifdef A_COLOR
     if (has_colors())
+    {
 	if (hit)
 	    attron(COLOR_PAIR(COLOR_RED));
 	else
 	    attron(COLOR_PAIR(COLOR_GREEN));
+    }
 #endif /* A_COLOR */
     (void) addch((chtype)hits[PLAYER][curx][cury]);
 #ifdef A_COLOR
@@ -882,12 +887,11 @@ static int plyturn(void)
 static int sgetc(const char *s)
 {
     const char *s1;
-    int ch;
 
     (void)refresh();
     for(;;)
     {
-	ch = getch();
+	int ch = getch();
 	if (islower(ch))
 	    ch = toupper(ch);
 	if (ch == CTRLC)
@@ -978,11 +982,13 @@ static int cpufire(int x, int y)
 
     pgoto(y, x);
 #ifdef A_COLOR
-    if (has_colors())
-	if (hit)
-	    attron(COLOR_PAIR(COLOR_RED));
-	else
-	    attron(COLOR_PAIR(COLOR_GREEN));
+	if (has_colors())
+	{
+	    if (hit)
+		attron(COLOR_PAIR(COLOR_RED));
+	    else
+		attron(COLOR_PAIR(COLOR_GREEN));
+	}
 #endif /* A_COLOR */
     (void)addch((chtype)(hit ? SHOWHIT : SHOWSPLASH));
 #ifdef A_COLOR
@@ -1154,10 +1160,11 @@ int playagain(void)
 
 static void do_options(int c, char *op[])
 {
-    register int i;
 
     if (c > 1)
     {
+	register int i;
+
 	for (i=1; i<c; i++)
 	{
 	    switch(op[i][0])
@@ -1175,8 +1182,8 @@ static void do_options(int c, char *op[])
 		switch(op[i][1])
 		{
 		case 'b':
-		    blitz = 1;
-		    if (salvo == 1)
+		    blitz = true;
+		    if (salvo)
 		    {
 			(void) fprintf(stderr,
 				"Bad Arg: -b and -s are mutually exclusive\n");
@@ -1184,8 +1191,8 @@ static void do_options(int c, char *op[])
 		    }
 		    break;
 		case 's':
-		    salvo = 1;
-		    if (blitz == 1)
+		    salvo = true;
+		    if (blitz)
 		    {
 			(void) fprintf(stderr,
 				"Bad Arg: -s and -b are mutually exclusive\n");
@@ -1193,7 +1200,7 @@ static void do_options(int c, char *op[])
 		    }
 		    break;
 		case 'c':
-		    closepack = 1;
+		    closepack = true;
 		    break;
 		default:
 		    (void) fprintf(stderr,
@@ -1272,6 +1279,7 @@ int main(int argc, char *argv[])
 	(playagain());
     uninitgame(0);
     /*NOTREACHED*/
+    return 0;
 }
 
 /* bs.c ends here */
